@@ -87,19 +87,23 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
                 {
                     GMM_ASSERTDPF(!CreateParams.Flags.Info.StdSwizzle, "StdSwizzle not supported on current platform");
 
-                    if(!GetGmmLibContext()->GetWaTable().WaDefaultTile4)
+                    if(!GetGmmLibContext()->GetSkuTable().FtrForceTile4) // FtrForceTile4 should never be set by default, used for debug purpose only
                     {
                         // Default Tiling is set to Tile64 on FtrTileY disabled platforms
-                        uint8_t IsYUVSurface = ((GmmIsPlanar(CreateParams.Format) &&
-                                                 (!((CreateParams.Format == GMM_FORMAT_BGRP) || (CreateParams.Format == GMM_FORMAT_RGBP)))) ||
-                                                (GmmIsYUVPacked(CreateParams.Format)));
+                        uint8_t IsYUVSurface = GmmIsPlanar(CreateParams.Format) ||
+                                                (GmmIsYUVPacked(CreateParams.Format));
+
+                        //YCRCB* formats
+                        uint8_t IsYCrCbSurface = ((CreateParams.Format == GMM_FORMAT_YCRCB_NORMAL) ||
+                                                  (CreateParams.Format == GMM_FORMAT_YCRCB_SWAPUV) ||
+                                                  (CreateParams.Format == GMM_FORMAT_YCRCB_SWAPUVY) || (CreateParams.Format == GMM_FORMAT_YCRCB_SWAPY));
 
 			CreateParams.Flags.Info.Tile4 = ((!GMM_IS_SUPPORTED_BPP_ON_TILE_64_YF_YS(BitsPerPixel)) ||            // 24,48,96 bpps are not supported on Tile64, Tile4 is bpp independent
                                                          ((CreateParams.Type == RESOURCE_3D) && (CreateParams.Flags.Gpu.Depth || CreateParams.Flags.Gpu.SeparateStencil)) ||
                                                          ((!GetGmmLibContext()->GetSkuTable().FtrDisplayDisabled) &&
                                                           (CreateParams.Flags.Gpu.FlipChain || CreateParams.Flags.Gpu.Overlay)
                                                           ) ||
-							  IsYUVSurface);
+							  IsYUVSurface || IsYCrCbSurface);
 
 			CreateParams.Flags.Info.Tile64 = !CreateParams.Flags.Info.Tile4;
                         // Optimize only when GMM makes tiling decision on behalf of UMD clients.
@@ -121,7 +125,7 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
                     GMM_ASSERTDPF(0, "Tile Yf/Ys not supported on given platform");
 
                     // Overrides the flags.
-                    if(GetGmmLibContext()->GetWaTable().WaDefaultTile4)
+                    if(GetGmmLibContext()->GetSkuTable().FtrForceTile4)// FtrForceTile4 should never be set by default, used for debug purpose only.
                     {
                         CreateParams.Flags.Info.Tile64 = CreateParams.Flags.Info.TiledYs ||
                                                          (CreateParams.MSAA.NumSamples > 1) || CreateParams.Flags.Gpu.TiledResource; // Colour & Depth/Stencil(IMS) MSAA should use Tile64
@@ -144,8 +148,7 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
 
                 // On Xe_HP onwards translate UMD's TileY/TileYs request to Tile4/Tile64 respectively
                 // Exclude TileX, Linear from override
-                if(GetGmmLibContext()->GetWaTable().WaDefaultTile4 && (CreateParams.Flags.Info.TiledYs ||
-                                                                       CreateParams.Flags.Info.TiledY))
+                if((GetGmmLibContext()->GetSkuTable().FtrForceTile4) && (CreateParams.Flags.Info.TiledYs || CreateParams.Flags.Info.TiledY))
                 {
                     CreateParams.Flags.Info.Tile64 =
                     CreateParams.Flags.Info.TiledYs ||
@@ -242,7 +245,7 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
                                      GMM_GTT_CACHETYPE_UNCACHED;
     }
 
-    if(GetGmmLibContext()->GetSkuTable().FtrCameraCaptureCaching == FALSE &&
+    if(GetGmmLibContext()->GetSkuTable().FtrCameraCaptureCaching == false &&
        CreateParams.Flags.Gpu.CameraCapture)
     {
         Surf.Flags.Info.Cacheable = 0;
@@ -281,14 +284,20 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
     }
 
     // Memory optimization for 64KB tiled Surface.
-    if(GetGmmLibContext()->GetWaTable().WaTile64Optimization && Optimize64KBTile)
+    if (!GetGmmLibContext()->GetSkuTable().FtrTileY)
     {
-        if(pTextureCalc->SurfaceRequires64KBTileOptimization(&Surf))
+        if ((GetGmmLibContext()->GetWaTable().WaTile64Optimization || GetGmmLibContext()->GetSkuTable().FtrTile64Optimization) && Optimize64KBTile)
         {
-            GMM_SET_64KB_TILE(Surf.Flags, 0, GetGmmLibContext());
-            GMM_SET_4KB_TILE(Surf.Flags, 1, GetGmmLibContext());
-            GMM_SET_64KB_TILE(CreateParams.Flags, 0, GetGmmLibContext());
-            GMM_SET_4KB_TILE(CreateParams.Flags, 1, GetGmmLibContext());
+            if (pTextureCalc->SurfaceRequires64KBTileOptimization(&Surf))
+            {
+                GMM_SET_64KB_TILE(Surf.Flags, 0, GetGmmLibContext());
+                GMM_SET_4KB_TILE(Surf.Flags, 1, GetGmmLibContext());
+
+                //Also update CreateParams, if client reuses the modified struct, it'd see final tile-selection by Gmm.
+                //Gmm's auto-tile-selection & tile-mode for size-optimization doesn't work for explicit tile-selection
+                GMM_SET_64KB_TILE(CreateParams.Flags, 0, GetGmmLibContext());
+                GMM_SET_4KB_TILE(CreateParams.Flags, 1, GetGmmLibContext());
+            }
         }
     }
 
@@ -309,7 +318,13 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
             AuxSurf.Type                         = (AuxSurf.Flags.Gpu.HiZ) ? AuxSurf.Type : RESOURCE_INVALID;
             AuxSurf.Flags.Info.RenderCompressed = AuxSurf.Flags.Info.MediaCompressed = 0;
         }
-        else if(Surf.Flags.Gpu.SeparateStencil && Surf.Flags.Gpu.CCS) //Stencil compression
+        else if(Surf.Flags.Gpu.Depth && Surf.Flags.Gpu.HiZ && !Surf.Flags.Gpu.CCS) // Depth + HiZ only, CCS is disabled
+        {
+            // main surface is depth, AuxSurf is HiZ
+            Surf.Flags.Gpu.HiZ                   = 0; //depth buffer, clear HiZ
+            AuxSurf.Flags.Gpu.IndirectClearColor = 0; //Clear fastClear from HiZ
+        }
+	else if(Surf.Flags.Gpu.SeparateStencil && Surf.Flags.Gpu.CCS) //Stencil compression
         {
             AuxSurf.Flags.Gpu.SeparateStencil = 0;
             Surf.Flags.Gpu.CCS                = 0;
