@@ -596,7 +596,7 @@ void GmmLib::GmmGen9TextureCalc::Fill2DTexOffsetAddress(GMM_TEXTURE_INFO *pTexIn
            ((pTexInfo->MSAA.NumSamples == 8) || (pTexInfo->MSAA.NumSamples == 16)) &&
            ((pTexInfo->Flags.Gpu.Depth == 0) && (pTexInfo->Flags.Gpu.SeparateStencil == 0)))
         {
-            ArrayQPitch *= 4; /* Aligned height of 4 samples */
+           // ArrayQPitch *= 4; /* Aligned height of 4 samples */
         }
 	    
         pTexInfo->Alignment.QPitch = ArrayQPitch;
