@@ -306,7 +306,7 @@ protected:
             { { 256, 256 },{ 512, 128 },{ 512, 128 },{ 1024, 64 },{ 1024, 64 } },   //TileYs
             { { 64, 64 },{ 128, 32 },{ 128, 32 },{ 256, 16 },{ 256, 16 } }     //TileYf
         };
-        uint32_t WMul, HMul;
+        uint32_t WMul = 1, HMul = 1;
 
         HAlign = 16;                              // RT H/VAlign
         VAlign = 4;
@@ -448,6 +448,21 @@ protected:
         }
     }
 
+    /////////////////////////////////////////////////////////////////////////////////////
+    /// Verifies if AuxCCSize matches the expected value.  Fails test if value doesn't match
+    ///
+    /// @param[in]  ResourceInfo: ResourceInfo returned by GmmLib
+    /// @param[in]  ExpectedValue: expected value to check against
+    /////////////////////////////////////////////////////////////////////////////////////
+    template <bool Verify>
+    void VerifyResourceAuxCCSize(GMM_RESOURCE_INFO *ResourceInfo, uint64_t ExpectedValue)
+    {
+        if(Verify)
+        {
+            EXPECT_EQ(ExpectedValue, ResourceInfo->GetSizeAuxSurface(GMM_AUX_CC));
+        }
+    }
+
     /////////////////////////////////////////////////////////////////////////////////////
     /// Verifies if QPitch matches the expected value.  Fails test if value doesn't match
     ///
