@@ -130,7 +130,6 @@ typedef struct GMM_RESOURCE_ALIGNMENT_REC
     uint32_t   PackedMipHeight;        // Packed Mip Height in # of 64KB Tiles (Pre-Gen9 / Undefined64KBSwizzle)
     uint32_t   QPitch;                 // Programmable QPitch (BDW+)
 }GMM_RESOURCE_ALIGNMENT;
-
 //===========================================================================
 // typedef:
 //        GMM_PAGETABLE_MGR
@@ -473,9 +472,10 @@ typedef enum
     GMM_MAIN_PLUS_AUX_SURF,  // Main surface plus auxilary data, includes ccs, cc, zcs, mcs metadata. Renderable portion of the surface.
     GMM_TOTAL_SURF,          // Main+Aux with additional padding based on hardware PageSize.
     GMM_MAPGPUVA_SIZE = GMM_TOTAL_SURF,// To be used for mapping gpu virtual address space.
+    GMM_TOTAL_SURF_PHYSICAL,
+    GMM_MAIN_SURF_PHYSICAL,
 } GMM_SIZE_PARAM;
 
-
 //===========================================================================
 // typedef:
 //        GMM_RES_COPY_BLT
@@ -529,6 +529,8 @@ typedef enum
     GMM_MAPPING_NULL = 0,
     GMM_MAPPING_LEGACY_Y_TO_STDSWIZZLE_SHAPE,
     GMM_MAPPING_GEN9_YS_TO_STDSWIZZLE,
+    GMM_MAPPING_YUVPLANAR,
+    GMM_MAPPING_YUVPLANAR_AUX,
 } GMM_GET_MAPPING_TYPE;
 
 typedef struct GMM_GET_MAPPING_REC
@@ -540,7 +542,7 @@ typedef struct GMM_GET_MAPPING_REC
         GMM_GFX_SIZE_T      VirtualOffset;
         GMM_GFX_SIZE_T      PhysicalOffset;
         GMM_GFX_SIZE_T      Size;
-    }                   Span, __NextSpan;
+    } Span, __NextSpan;
 
     struct
     {
@@ -553,11 +555,9 @@ typedef struct GMM_GET_MAPPING_REC
             GMM_GFX_SIZE_T      Physical, Virtual;
         }                   Slice0MipOffset, SlicePitch;
         uint32_t               EffectiveLodMax, Lod, Row, RowPitchVirtual, Rows, Slice, Slices;
-        GMM_YUV_PLANE       Plane, LastPlane;
+        GMM_YUV_PLANE Plane, LastPlane;
     }                   Scratch; // Zero on initial call to GmmResGetMappingSpanDesc and then let persist.
 } GMM_GET_MAPPING;
-
-
 //***************************************************************************
 //
 //                      GMM_RESOURCE_INFO API
@@ -724,7 +724,8 @@ uint32_t                    GMM_STDCALL GmmCachePolicyGetMaxSpecialMocsIndex(voi
 
 
 void                        GMM_STDCALL GmmResSetPrivateData(GMM_RESOURCE_INFO *pGmmResource, void *pPrivateData);
-
+uint32_t                    GMM_STDCALL GmmCachePolicyGetPATIndex(void *pLibContext, GMM_RESOURCE_USAGE_TYPE Usage, bool *pCompressionEnable, bool IsCpuCacheable);
+uint8_t                     GMM_STDCALL GmmGetSurfaceStateL2CachePolicy(void *pLibContext, GMM_RESOURCE_USAGE_TYPE Usage);
 #if (!defined(__GMM_KMD__) && !defined(GMM_UNIFIED_LIB))
 /////////////////////////////////////////////////////////////////////////////////////
 /// C wrapper functions for UMD clients Translation layer from OLD GMM APIs to New
