@@ -107,7 +107,8 @@ typedef struct _SKU_FEATURE_TABLE
 	unsigned int   FtrDisplayPageTables             : 1;  // Display Page Tables: 2-Level Page walk for Displayable Frame buffers in GGTT.
         unsigned int   Ftr57bGPUAddressing              : 1;  // 57b GPUVA support eg: PVC
 	unsigned int   FtrUnified3DMediaCompressionFormats : 1; // DG2 has unified Render/media compression(versus TGLLP/XeHP_SDV 's multiple instances) and requires changes to RC format h/w encodings.
-
+        unsigned int   FtrForceTile4                    : 1;  // Flag to force Tile4 usage as default in Tile64 supported platforms.
+        unsigned int   FtrTile64Optimization            : 1;
     };
 
 
@@ -527,6 +528,12 @@ typedef struct _WA_TABLE
         WA_BUG_TYPE_PERF,
         WA_BUG_PERF_IMPACT_UNKNOWN, WA_COMPONENT_GMM)
 
+        WA_DECLARE(
+        Wa_22016140776,
+        "[PVC] operation unexpectedly results in NAN",
+        WA_BUG_TYPE_UNKNOWN,
+        WA_BUG_PERF_IMPACT_UNKNOWN, WA_COMPONENT_UNKNOWN)
+
 } WA_TABLE, *PWA_TABLE;
 
 //********************************** SKU/WA Macros *************************************
